# Version 0.1.3 (2022-10-02)
* Add derivative computation for fully-connected layer (CPU & CUDA)
* Add Long Short-Term Memory (LSTM) with TAGI (CPU & CUDA)
* Add dataloader for time series


# Version 0.1.2 (2022-07-09)
* Add homoscedastic & heteroscedastic noise inferences 
* Support docker images 

# Version 0.1.1 (2022-05-31)
* Support CPU with multithreading for only fully-connected layer
* Regression, classification, and autoencoder are working
* Changes Makefile to CMakeLists.txt

# Version 0.1.0 (2022-04-26)
* Initial release of cuTAGI
* classification is working
* Support Ubuntu with a NIVDIA GPU and CUDA toolkit >=10.1